
require 'ripple_oh_caramba'


class Car
  include Ripple::Document

  reference_one :rival, :class => Car
end




describe 'reference_one' do
  it 'gives error when given unpersisted class' do
    lambda do
      Car.new(:rival => Car.new)
    end.should raise_error
  end

  it 'works' do
    rival = Car.create
    car = Car.new(:rival => rival)

    car.rival.should == rival
    car.rival_key.should == rival.key

    car.save
    Car.find(car.key).rival.should == car.rival
    Car.find(car.key).rival_key.should == car.rival.key

    rival.destroy
    car.destroy
  end
end

class Wanderer
  include Ripple::Document

  reference_many :friends, :class => Wanderer
end



describe 'reference_many' do
  it 'works' do
    mitch     = Wanderer.create
    george    = Wanderer.create
    wanderer  = Wanderer.new(:friends => [mitch, george])

    wanderer.friends.should == [mitch, george]
    wanderer.save
    wanderer.friend_keys.should == [mitch.key, george.key]

    Wanderer.find(wanderer.key).friends.should == [mitch, george]
    Wanderer.find(wanderer.key).friend_keys.should ==
                                          [mitch.key, george.key]

    [mitch, george, wanderer].each {|w| w.destroy }
  end
end

describe 'reference_one_mutual' do
  it 'works'
  # and handles options
end

describe 'reference_many_mutual' do
  it 'works'
  # and handles options
end

describe 'token_key!' do
  it 'works'
  # and handles options
end

describe 'token' do
  it 'works'
  # and handles options
end



